==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/EC2/CancelBundleTask.pm <==

package Paws::EC2::CancelBundleTask;
  use Moose;
  has BundleId => (is => 'ro', isa => 'Str', required => 1);
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelBundleTask');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CancelBundleTaskResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CancelBundleTask - Arguments for method CancelBundleTask on Paws::EC2

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelBundleTask on the 
Amazon Elastic Compute Cloud service. Use the attributes of this class
as arguments to method CancelBundleTask.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CancelBundleTask.

As an example:

  $service_obj->CancelBundleTask(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> BundleId => Str

The ID of the bundle task.



=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelBundleTask in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/EC2/CancelBundleTask.pm <==

package Paws::EC2::CancelBundleTask;
  use Moose;
  has BundleId => (is => 'ro', isa => 'Str', required => 1);
  has DryRun => (is => 'ro', isa => 'Bool', traits => ['NameInRequest'], request_name => 'dryRun' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'CancelBundleTask');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::EC2::CancelBundleTaskResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::EC2::CancelBundleTask - Arguments for method CancelBundleTask on L<Paws::EC2>

=head1 DESCRIPTION

This class represents the parameters used for calling the method CancelBundleTask on the
L<Amazon Elastic Compute Cloud|Paws::EC2> service. Use the attributes of this class
as arguments to method CancelBundleTask.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to CancelBundleTask.

=head1 SYNOPSIS

    my $ec2 = Paws->service('EC2');
    my $CancelBundleTaskResult = $ec2->CancelBundleTask(
      BundleId => 'MyString',
      DryRun   => 1,            # OPTIONAL
    );

    # Results:
    my $BundleTask = $CancelBundleTaskResult->BundleTask;

    # Returns a L<Paws::EC2::CancelBundleTaskResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/ec2/CancelBundleTask>

=head1 ATTRIBUTES


=head2 B<REQUIRED> BundleId => Str

The ID of the bundle task.



=head2 DryRun => Bool

Checks whether you have the required permissions for the action,
without actually making the request, and provides an error response. If
you have the required permissions, the error response is
C<DryRunOperation>. Otherwise, it is C<UnauthorizedOperation>.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method CancelBundleTask in L<Paws::EC2>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
